@@ -44,8 +44,8 @@ check_gui_deps <- function(abort = TRUE) {
       type = ifelse(abort, "error", "warning"),
       "Some missing packages are needed to run the GUI; ",
       "please install them with the command \n",
-      " > install.packages(\"",
-      paste(names(gui_deps_missing)[gui_deps_missing], collapse = "\", \""),"\")"
+      " > install.packages(c(\"",
+      paste(names(gui_deps_missing)[gui_deps_missing], collapse = "\", \""),"\"))"
     )
     invisible(TRUE)
   } else {
